@@ -30,4 +30,8 @@ typedef uint16_t    u_int16_t;
 typedef uint32_t    u_int32_t;
 typedef uint64_t    u_int64_t;
 
+#ifndef BYTE_ORDER
+#include <machine/endian.h>
+#endif
+
 #endif
