@@ -8,12 +8,18 @@
 #ifndef LIBCOMPAT_UNISTD_H
 #define LIBCOMPAT_UNISTD_H
 
+#define pledge(request, paths) 0
+
 #ifndef HAVE_GETENTROPY
 int getentropy(void *buf, size_t buflen);
 #endif
 
 #include <grp.h>
 
+#ifndef HAVE_CLOSEFROM
+int closefrom(int fd);
+#endif
+
 #ifndef HAVE_SETGROUPS
 int setgroups(int ngroups, const gid_t *gidset);
 #endif
