@@ -1,4 +1,4 @@
-/*	$OpenBSD: ntpd.h,v 1.128 2016/01/27 21:36:25 bcook Exp $ */
+/*	$OpenBSD: ntpd.h,v 1.129 2016/01/27 21:48:34 reyk Exp $ */
 
 /*
  * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
@@ -50,12 +50,6 @@
 #define	DRIFTFILE	LOCALSTATEDIR "/db/ntpd.drift"
 #define	CTLSOCKET	LOCALSTATEDIR "/run/ntpd.sock"
 
-#if defined(SO_SETFIB)
-#define	SO_RTABLE	SO_SETFIB
-#define	SIOCGIFRDOMAIN	SIOCGIFFIB
-#define	ifr_rdomainid	ifr_fib
-#endif
-
 #define	INTERVAL_QUERY_NORMAL		30	/* sync to peers every n secs */
 #define	INTERVAL_QUERY_PATHETIC		60
 #define	INTERVAL_QUERY_AGGRESSIVE	5
@@ -284,11 +278,6 @@ struct ctl_show_sensor {
 	double		 correction;
 };
 
-enum blockmodes {
-	BM_NORMAL,
-	BM_NONBLOCK
-};
-
 struct ctl_conn {
 	TAILQ_ENTRY(ctl_conn)	entry;
 	struct imsgbuf		ibuf;
@@ -414,7 +403,7 @@ int			 control_accept(int);
 struct ctl_conn		*control_connbyfd(int);
 int			 control_close(int);
 int			 control_dispatch_msg(struct pollfd *, u_int *);
-void			 session_socket_blockmode(int, enum blockmodes);
+void			 session_socket_nonblockmode(int);
 void			 build_show_status(struct ctl_show_status *);
 void			 build_show_peer(struct ctl_show_peer *,
 			     struct ntp_peer *);
